=== modified file 'examples/simple.cc'
--- examples/simple.cc	2011-08-20 13:33:56 +0000
+++ examples/simple.cc	2011-08-20 14:28:25 +0000
@@ -84,15 +84,17 @@
 
   drizzle::drizzle_c drizzle;
   drizzle::connection_c* con= new drizzle::connection_c(drizzle);
-  con->set_tcp(host, port);
-  con->set_auth(user, password);
+  if (host || port)
+    con->set_tcp(host, port);
+  if (user || password)
+    con->set_auth(user, password);
   con->set_db("information_schema");
   drizzle::query_c q(*con, "select table_schema, table_name from tables where table_name like ?");
   q.p("%");
-  cout << q.read() << endl;
   try
   {
     drizzle::result_c result= q.execute();
+    cout << q.read() << endl;
     while (drizzle_row_t row= result.row_next())
     {
       for (int x= 0; x < result.column_count(); x++)

=== modified file 'libdrizzle-2.0/libdrizzle/libdrizzle.hpp'
--- libdrizzle-2.0/libdrizzle/libdrizzle.hpp	2011-08-20 13:33:56 +0000
+++ libdrizzle-2.0/libdrizzle/libdrizzle.hpp	2011-08-20 14:28:25 +0000
@@ -33,9 +33,13 @@
 
 #pragma once
 
+#include <boost/algorithm/string.hpp>
+#include <boost/foreach.hpp>
 #include <boost/shared_ptr.hpp>
 #include <cstring>
+#include <fstream>
 #include <libdrizzle/libdrizzle.h>
+#include <map>
 #include <sstream>
 #include <stdexcept>
 
@@ -145,6 +149,7 @@
   explicit connection_c(drizzle_c& drizzle)
   {
     drizzle_con_create(drizzle, *this);
+    read_conf_files();
   }
 
   ~connection_c()
@@ -214,6 +219,8 @@
     return query(str, strlen(str));
   }
 private:
+  void read_conf_files();
+
   drizzle_con_st b_;
 };
 
@@ -302,4 +309,68 @@
   std::string out_;
 };
 
+template<class T>
+const char* get_conf(const T& c, const std::string& v)
+{
+  typename T::const_iterator i = c.find(v);
+  return i == c.end() ? NULL : i->second.c_str();
+}
+
+void connection_c::read_conf_files()
+{
+  using namespace std;
+
+  vector<string> conf_files;
+#ifdef WIN32
+  {
+    boost::array<char, MAX_PATH> d;
+    GetWindowsDirectoryA(d.data(), d.size());
+    conf_files.push_back(string(d.data()) + "/my.cnf");
+    conf_files.push_back(string(d.data()) + "/drizzle.cnf");
+    conf_files.push_back(string(d.data()) + "/drizzle.conf");
+  }
+#else
+  conf_files.push_back("/etc/mysql/my.cnf");
+  conf_files.push_back("/etc/drizzle/drizzle.cnf");
+  conf_files.push_back("/etc/drizzle/drizzle.conf");
+#endif
+  if (const char* d = getenv("HOME"))
+  {
+    conf_files.push_back(string(d) + "/.my.cnf");  
+    conf_files.push_back(string(d) + "/.drizzle.conf");
+  }
+  
+  typedef map<string, string> conf_t;
+  conf_t conf;
+  BOOST_FOREACH(string& it, conf_files)
+  {
+    ifstream is(it.c_str());
+    bool client_section = false;
+    for (string s; getline(is, s); )
+    {
+      size_t i = s.find('#');
+      if (i != string::npos)
+        s.erase(i);
+      boost::trim(s);
+      if (boost::starts_with(s, "["))
+      {
+        client_section = s == "[client]";
+        continue;
+      }
+      else if (!client_section)
+        continue;
+      i = s.find('=');
+      if (i == string::npos)
+        continue;
+      conf[boost::trim_copy(s.substr(0, i))] = boost::trim_copy(s.substr(i + 1));
+      if (s.empty() || !client_section)
+        continue;
+    }
+  }
+  if (conf.count("host") || conf.count("port"))
+    set_tcp(get_conf(conf, "host"), atoi(get_conf(conf, "port")));
+  if (conf.count("user") || conf.count("password"))
+    set_auth(get_conf(conf, "user"), get_conf(conf, "password"));
+}
+
 }

